/* TestEntry.java
 *
 * created: Mon Oct 12 1998
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1998,1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/TestEntry.java,v 1.22 1999/05/21 08:23:15 kmr Exp $
 */

import uk.ac.sanger.pathogens.embl.*;
import uk.ac.sanger.pathogens.*;

import diana.Options;

import java.io.*;
import java.util.Vector;

/**
 *  TestEntry class
 *
 *  @author Kim Rutherford
 *  @version $Id: TestEntry.java,v 1.22 1999/05/21 08:23:15 kmr Exp $
 *
 */

public class TestEntry {
  /**
   *
   */
  static public void main (String [] args) {
    final String install_path =
      System.getProperties ().getProperty ("diana.install.path");

    if (install_path == null || install_path.length () == 0) {
      throw new Error ("the diana.install.path property was not set on the " +
                       "command line");
    } else {
      setCodeDirectory (new FileDocument (new File (install_path)));
    }

    try {
      final StringVector extra_keys =
        getOptions ().getOptionValues ("extra_keys");

      final QualifierInfoVector extra_qualifiers =
        getOptions ().getExtraQualifiers ();

      final Document feature_keys_document =
        getCodeDirectory ().append ("etc").append ("feature_keys");

      final Document qualifier_document =
        getCodeDirectory ().append ("etc").append ("qualifier_types");
 
      EntryInformation.initialise (feature_keys_document,
                                   qualifier_document,
                                   extra_keys,
                                   extra_qualifiers);
    } catch (IOException e) {
      System.out.println ("could not initialise the embl package: " +
                          e.getMessage ());
      System.exit (1);
    } catch (QualifierInfoException e) {
      System.out.println ("could not initialise the embl package: " +
                          e.getMessage ());
      System.exit (1);
    }

    for (int j = 0 ; j < args.length ; ++j) {
      try {

        File file = new File (args[j]);

        FileReader in_file = new FileReader (file);

        final uk.ac.sanger.pathogens.embl.LinePushBackReader pushback_reader =
          new uk.ac.sanger.pathogens.embl.LinePushBackReader (in_file);

        Vector entries = new Vector ();
      
        int i = 0;
      
        final Document new_document = new FileDocument (file);

        DocumentEntry entry = new DocumentEntry (new_document);
      
//        entries.addElement (entry);

//        Writer writer = new OutputStreamWriter (System.out);

        //      entry.writeEMBL (writer);

//        writer.close ();
        
        //          FeatureTable feature_table = entry.getFeatureTable ();

        //          if (feature_table == null) {
        //  //          System.out.println ("No feature table");
        //          } else {

        //            FeatureVector features = feature_table.getFeatures ();
          
        //            if (features == null) {
        //              System.out.println ("No feature table");
        //            } else {
        //              i += features.size ();
        //              final LocationParseNode node =
        //                features.elementAt (0).getLocation ().getParsedLocation ();
        //  //            System.out.println ("location: " + node.toString ());
        //              if (node == null) {
        //                System.out.println ("getCanonical () failed");
        //              }
        //            }
        //          }

        //         System.out.println ("Entry features: " + i);

        //         final String seq_string = entry.getSequence ().toString ();

        //         System.out.println ("Sequence start: " + seq_string.substring (0,9));

        //         final int seq_length = seq_string.length ();

        //         System.out.println ("Sequence end: " +
        //                             seq_string.substring (seq_length-9, seq_length));

        //         System.out.println ("Sequence length: " + seq_length);
        

        //         final diana.sequence.Bases bases =
        //           new diana.sequence.Bases (entry.getSequence ());

        //         final diana.sequence.StrandPair pair =
        //           new diana.sequence.StrandPair (bases);


        //         final diana.sequence.Strand forward = pair.getForwardStrand ();
        //         final diana.sequence.Strand reverse = pair.getBackwardStrand ();

        //         System.out.println ("forward translation: " +
        //                             forward.getTranslation (new Range (1,2000)));
        //         System.out.println ("reverse translation: " +
        //                             reverse.getTranslation (new Range (1,1000)));
        //         System.out.println ("translation: " +
        //                             bases.getTranslation (new Range (1,9),
        //                                                   diana.sequence.Bases.FORWARD));


        //        char [] buf = new char [1000];

        //        in_file.read (buf, 0, 1000);
        
        //        System.out.println ("in main (): " + buf);

      
      } catch (Exception e) {
        System.out.println (args[0] + ": " + e);
      }
    }

    System.exit (0);
  }

  static public Options getOptions () {
    if (options == null) {
      options = new Options ();

      try {
        final InputStream options_input_stream =
          getCodeDirectory ().append ("options").getInputStream ();

        options.load (options_input_stream);

          final Document current_directory_options_document =
            new FileDocument (new File ("options"));

          // read the options file from the current directory if it is there
          if (current_directory_options_document.readable ()) {

            final InputStream current_directory_options_stream =
              current_directory_options_document.getInputStream ();

            options.load (current_directory_options_stream);
          }

          final Document current_directory_dot_ini_document =
            new FileDocument (new File ("diana.ini"));

          // read the "diana.ini" file from the current directory if it is
          // there
          if (current_directory_dot_ini_document.readable ()) {

            final InputStream current_directory_dot_ini_stream =
              current_directory_dot_ini_document.getInputStream ();

            options.load (current_directory_dot_ini_stream);
          }
      } catch (IOException e) {
        System.out.println ("could not read the options file - " + e);
// XXX
//          new MessageDialog (this,
//                             "could not read the options file - " +
//                             e.getMessage ());
      }
    }
    return options;
  }
  public static Document getCodeDirectory () {
    return code_directory;
  }

  static void setCodeDirectory (Document code_directory) {
    TestEntry.code_directory = code_directory;
  }

  static private Document code_directory = null;

  static private Options options = null;
}
